gimap_stats: Do tests -an internal function used by calc_gi() function

View source: R/05-calculate_gi.R

gimap_statsR Documentation

Do tests –an internal function used by calc_gi() function

Description

Create results table that has t test p values

Usage

gimap_stats(gi_calc_double, gi_calc_single, use_ntc = TRUE, replicate = NULL)

Arguments

gi_calc_double

a data.frame with adjusted double gi scores

gi_calc_single

a data.frame with adjusted single gi scores

use_ntc

Logical. If TRUE, uses a two-sample t-test comparing double target GI scores against single target GI scores. If FALSE, uses a one-sample t-test against mu=0 since single target GI scores have zero variance when negative controls are not used.

replicate

a name of a replicate to filter out from gi_calc_adj Optional


gimap documentation built on July 10, 2026, 1:06 a.m.