| get_example_data | R Documentation |
This function loads and returns example data for the package. Which dataset is returned must be specified. Data will be downloaded from Figshare the first time it is used.
get_example_data(which_data, data_dir = NULL, refresh_data = FALSE)
which_data |
One of '"count"', '"count_treatment"', '"meta"', '"gimap"', '"gimap_treatment"', or '"annotation"'; specifies which example dataset is returned. |
data_dir |
Where files are stored. If 'NULL' (default), example files are written under 'file.path(tempdir(), "gimap-example-data")' for the current R session (they are not kept after the session ends). Pass an explicit directory if you want a persistent copy (for example to mirror files elsewhere). |
refresh_data |
If 'TRUE', removes known example filenames from 'data_dir' (only under safe locations; see [delete_example_data()]) before re-downloading. |
the respective example data either as a data frame or a specialized gimap_dataset depending on what was requested.
## Not run:
counts_timepoint <- get_example_data("count")
counts_treatment <- get_example_data("count_treatment")
gimap_timepoint_dataset <- get_example_data("gimap")
gimap_treatment_dataset <- get_example_data("gimap_treatment")
metadata <- get_example_data("meta")
annotation <- get_example_data("annotation")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.