View source: R/05-calculate_gi.R
| gimap_stats | R Documentation |
Create results table that has t test p values
gimap_stats(gi_calc_double, gi_calc_single, use_ntc = TRUE, replicate = NULL)
gi_calc_double |
a data.frame with adjusted double gi scores |
gi_calc_single |
a data.frame with adjusted single gi scores |
use_ntc |
Logical. If TRUE, uses a two-sample t-test comparing double target GI scores against single target GI scores. If FALSE, uses a one-sample t-test against mu=0 since single target GI scores have zero variance when negative controls are not used. |
replicate |
a name of a replicate to filter out from gi_calc_adj Optional |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.